Process Module
==============

.. contents::
    :local:

This module contains the utilities to :class:`parse <emva1288.process.parser.ParseEmvaDescriptorFile>`
descriptor file, :class:`load <emva1288.process.loader.LoadImageData>` image data,
:class:`process <emva1288.process.data.Data1288>` image data to generate
:class:`results <emva1288.process.results.Results1288>` according to the EMVA1288 standart.
Results can then be :class:`plotted <emva1288.process.plotting.Plotting1288>` according
to the standart.

:mod:`~emva1288.process.data`
-----------------------------

.. automodule:: emva1288.process.data
    :members:
    :undoc-members:
    :show-inheritance:
    :private-members:
    :special-members: __init__

:mod:`~emva1288.process.loader`
-------------------------------

.. automodule:: emva1288.process.loader
    :members:
    :undoc-members:
    :show-inheritance:
    :special-members: __init__

:mod:`~emva1288.process.parser`
-------------------------------

.. automodule:: emva1288.process.parser
    :members:
    :undoc-members:
    :show-inheritance:
    :special-members: __init__

:mod:`~emva1288.process.plotting`
---------------------------------

.. automodule:: emva1288.process.plotting
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`~emva1288.process.results`
--------------------------------

.. automodule:: emva1288.process.results
    :members:
    :undoc-members:
    :show-inheritance:
    :special-members: __init__

:mod:`~emva1288.process.routines`
---------------------------------

.. automodule:: emva1288.process.routines
    :members:
    :undoc-members:
    :show-inheritance:
